@@ -27,10 +27,7 @@
 #include <gdk/gdk.h>
 #include <stdlib.h>
 #include <lcms2.h>
-
-#ifdef HAVE_LIBCANBERRA
 #include <canberra-gtk.h>
-#endif
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 #include <libgnome-desktop/gnome-rr.h>
@@ -197,29 +194,19 @@ gcm_session_get_output_id (GsdColorManager *manager, GnomeRROutput *output)
                          error->message);
                 g_error_free (error);
                 g_string_append_printf (device_id,
-                                        "-%s",
+                                        "_%s",
                                         gnome_rr_output_get_name (output));
                 goto out;
         }
 
-        /* check EDID data is okay to use */
+        /* get EDID data */
         vendor = gcm_edid_get_vendor_name (edid);
-        name = gcm_edid_get_monitor_name (edid);
-        serial = gcm_edid_get_serial_number (edid);
-        if (vendor == NULL && name == NULL && serial == NULL) {
-                g_debug ("edid invalid for %s, falling back to connection name",
-                         gnome_rr_output_get_name (output));
-                g_string_append_printf (device_id,
-                                        "-%s",
-                                        gnome_rr_output_get_name (output));
-                goto out;
-        }
-
-        /* use EDID data */
         if (vendor != NULL)
                 g_string_append_printf (device_id, "-%s", vendor);
+        name = gcm_edid_get_monitor_name (edid);
         if (name != NULL)
                 g_string_append_printf (device_id, "-%s", name);
+        serial = gcm_edid_get_serial_number (edid);
         if (serial != NULL)
                 g_string_append_printf (device_id, "-%s", serial);
 out:
@@ -366,7 +353,8 @@ gcm_session_profile_assign_find_device_cb (GObject *object,
                                                res,
                                                &error);
         if (device == NULL) {
-                g_warning ("not found device which should have been added: %s",
+                g_warning ("not found device %s which should have been added: %s",
+                           cd_device_get_id (device),
                            error->message);
                 g_error_free (error);
                 gcm_session_async_helper_free (helper);
@@ -558,7 +546,6 @@ gcm_apply_create_icc_profile_for_edid (GsdColorManager *manager,
         cmsToneCurve *transfer_curve[3] = { NULL, NULL, NULL };
         const gchar *data;
         gboolean ret = FALSE;
-        gchar *title = NULL;
         gfloat localgamma;
 #ifdef HAVE_NEW_LCMS
         cmsHANDLE dict = NULL;
@@ -635,12 +622,9 @@ gcm_apply_create_icc_profile_for_edid (GsdColorManager *manager,
         }
 
         /* write title */
-        title = g_strdup_printf ("%s, %s",
-                                 _("Default"),
-                                 data);
         ret = _cmsWriteTagTextAscii (lcms_profile,
                                      cmsSigProfileDescriptionTag,
-                                     title);
+                                     data);
         if (!ret) {
                 g_set_error_literal (error, GSD_COLOR_MANAGER_ERROR, GSD_COLOR_MANAGER_ERROR_FAILED, "failed to write description");
                 goto out;
@@ -724,7 +708,6 @@ gcm_apply_create_icc_profile_for_edid (GsdColorManager *manager,
         cmsSaveProfileToFile (lcms_profile, filename);
         ret = TRUE;
 out:
-        g_free (title);
 #ifdef HAVE_NEW_LCMS
         if (dict != NULL)
                 cmsDictFree (dict);
@@ -760,7 +743,7 @@ gcm_session_generate_vcgt (CdProfile *profile, guint size)
                 goto out;
 
         /* get tone curves from profile */
-        vcgt = cmsReadTag (lcms_profile, cmsSigVcgtTag);
+        vcgt = cmsReadTag (lcms_profile, cmsSigVcgtType);
         if (vcgt == NULL || vcgt[0] == NULL) {
                 g_debug ("profile does not have any VCGT data");
                 goto out;
@@ -968,51 +951,6 @@ out:
         return output;
 }
 
-/* this function is more complicated than it should be, due to the
- * fact that XOrg sometimes assigns no primary devices when using
- * "xrandr --auto" or when the version of RANDR is < 1.3 */
-static gboolean
-gcm_session_use_output_profile_for_screen (GsdColorManager *manager,
-                                           GnomeRROutput *output)
-{
-        gboolean has_laptop = FALSE;
-        gboolean has_primary = FALSE;
-        GnomeRROutput **outputs;
-        GnomeRROutput *connected = NULL;
-        guint i;
-
-        /* do we have any screens marked as primary */
-        outputs = gnome_rr_screen_list_outputs (manager->priv->x11_screen);
-        if (outputs == NULL || outputs[0] == NULL) {
-                g_warning ("failed to get outputs");
-                return FALSE;
-        }
-        for (i = 0; outputs[i] != NULL; i++) {
-                if (!gnome_rr_output_is_connected (outputs[i]))
-                        continue;
-                if (connected == NULL)
-                        connected = outputs[i];
-                if (gnome_rr_output_get_is_primary (outputs[i]))
-                        has_primary = TRUE;
-                if (gnome_rr_output_is_laptop (outputs[i]))
-                        has_laptop = TRUE;
-        }
-
-        /* we have an assigned primary device, are we that? */
-        if (has_primary)
-                return gnome_rr_output_get_is_primary (output);
-
-        /* choosing the internal panel is probably sane */
-        if (has_laptop)
-                return gnome_rr_output_is_laptop (output);
-
-        /* we have to choose one, so go for the first connected device */
-        if (connected != NULL)
-                return gnome_rr_output_get_id (connected) == gnome_rr_output_get_id (output);
-
-        return FALSE;
-}
-
 static void
 gcm_session_device_assign_profile_connect_cb (GObject *object,
                                               GAsyncResult *res,
@@ -1047,8 +985,7 @@ gcm_session_device_assign_profile_connect_cb (GObject *object,
                 goto out;
 
         /* set the _ICC_PROFILE atom */
-        ret = gcm_session_use_output_profile_for_screen (manager, output);
-        if (ret) {
+        if (gnome_rr_output_get_is_primary (output)) {
                 ret = gcm_session_screen_set_icc_profile (manager,
                                                           filename,
                                                           &error);
@@ -1140,33 +1077,35 @@ gcm_session_device_assign_connect_cb (GObject *object,
                 goto out;
         }
 
-        /* create profile from device edid if it exists */
+        /* get the output EDID */
         edid = gcm_session_get_output_edid (manager, output, &error);
         if (edid == NULL) {
                 g_warning ("unable to get EDID for %s: %s",
                            cd_device_get_id (device),
                            error->message);
-                g_clear_error (&error);
+                g_error_free (error);
+                goto out;
+        }
 
+        /* create profile from device edid if it does not exist */
+        autogen_filename = g_strdup_printf ("edid-%s.icc",
+                                            gcm_edid_get_checksum (edid));
+        autogen_path = g_build_filename (g_get_user_data_dir (),
+                                         "icc", autogen_filename, NULL);
+
+        if (g_file_test (autogen_path, G_FILE_TEST_EXISTS)) {
+                g_debug ("auto-profile edid %s exists", autogen_path);
         } else {
-                autogen_filename = g_strdup_printf ("edid-%s.icc",
-                                                    gcm_edid_get_checksum (edid));
-                autogen_path = g_build_filename (g_get_user_data_dir (),
-                                                 "icc", autogen_filename, NULL);
-                if (g_file_test (autogen_path, G_FILE_TEST_EXISTS)) {
-                        g_debug ("auto-profile edid %s exists", autogen_path);
-                } else {
-                        g_debug ("auto-profile edid does not exist, creating as %s",
-                                 autogen_path);
-                        ret = gcm_apply_create_icc_profile_for_edid (manager,
-                                                                     edid,
-                                                                     autogen_path,
-                                                                     &error);
-                        if (!ret) {
-                                g_warning ("failed to create profile from EDID data: %s",
-                                             error->message);
-                                g_clear_error (&error);
-                        }
+                g_debug ("auto-profile edid does not exist, creating as %s",
+                         autogen_path);
+                ret = gcm_apply_create_icc_profile_for_edid (manager,
+                                                             edid,
+                                                             autogen_path,
+                                                             &error);
+                if (!ret) {
+                        g_warning ("failed to create profile from EDID data: %s",
+                                     error->message);
+                        g_clear_error (&error);
                 }
         }
 
@@ -1280,9 +1219,9 @@ gcm_session_create_device_cb (GObject *object,
 static void
 gcm_session_add_x11_output (GsdColorManager *manager, GnomeRROutput *output)
 {
-        const gchar *model = NULL;
-        const gchar *serial = NULL;
-        const gchar *vendor = NULL;
+        const gchar *model;
+        const gchar *serial;
+        const gchar *vendor;
         gboolean ret;
         gchar *device_id = NULL;
         GcmEdid *edid;
@@ -1290,36 +1229,29 @@ gcm_session_add_x11_output (GsdColorManager *manager, GnomeRROutput *output)
         GHashTable *device_props = NULL;
         GsdColorManagerPrivate *priv = manager->priv;
 
-        /* try to get edid */
+        /* get edid */
         edid = gcm_session_get_output_edid (manager, output, &error);
         if (edid == NULL) {
                 g_warning ("failed to get edid: %s",
                            error->message);
-                g_clear_error (&error);
+                g_error_free (error);
+                goto out;
         }
 
-        /* prefer DMI data for the internal output */
+        /* is this an internal device? */
         ret = gnome_rr_output_is_laptop (output);
         if (ret) {
                 model = gcm_dmi_get_name (priv->dmi);
                 vendor = gcm_dmi_get_vendor (priv->dmi);
-        }
-
-        /* use EDID data if we have it */
-        if (edid != NULL) {
+        } else {
+                model = gcm_edid_get_monitor_name (edid);
                 if (model == NULL)
-                        model = gcm_edid_get_monitor_name (edid);
-                if (vendor == NULL)
-                        vendor = gcm_edid_get_vendor_name (edid);
-                if (serial == NULL)
-                        serial = gcm_edid_get_serial_number (edid);
+                        model = gnome_rr_output_get_name (output);
+                vendor = gcm_edid_get_vendor_name (edid);
         }
 
-        /* ensure mandatory fields are set */
-        if (model == NULL)
-                model = gnome_rr_output_get_name (output);
-        if (vendor == NULL)
-                vendor = "unknown";
+        /* get a serial number if one exists */
+        serial = gcm_edid_get_serial_number (edid);
         if (serial == NULL)
                 serial = "unknown";
 
@@ -1361,6 +1293,7 @@ gcm_session_add_x11_output (GsdColorManager *manager, GnomeRROutput *output)
                                  NULL,
                                  gcm_session_create_device_cb,
                                  manager);
+out:
         g_free (device_id);
         if (device_props != NULL)
                 g_hash_table_unref (device_props);
@@ -1476,7 +1409,8 @@ gcm_session_profile_gamma_find_device_cb (GObject *object,
                                                            res,
                                                            &error);
         if (device == NULL) {
-                g_warning ("could not find device: %s",
+                g_warning ("not found device %s: %s",
+                           cd_device_get_id (device),
                            error->message);
                 g_error_free (error);
                 goto out;
@@ -1616,7 +1550,7 @@ gsd_color_manager_start (GsdColorManager *manager,
         gnome_settings_profile_start (NULL);
 
         /* coldplug the list of screens */
-        priv->x11_screen = gnome_rr_screen_new (gdk_screen_get_default (), error);
+        priv->x11_screen = gnome_settings_session_get_screen (error);
         if (priv->x11_screen == NULL)
                 goto out;
 
@@ -1990,7 +1924,6 @@ gcm_session_profile_store_added_cb (GcmProfileStore *profile_store,
                                     const gchar *filename,
                                     GsdColorManager *manager)
 {
-        CdProfile *profile = NULL;
         gchar *checksum = NULL;
         gchar *profile_id = NULL;
         GError *error = NULL;
@@ -2030,8 +1963,6 @@ out:
         g_free (profile_id);
         if (profile_props != NULL)
                 g_hash_table_unref (profile_props);
-        if (profile != NULL)
-                g_object_unref (profile);
 }
 
 static void
@@ -2097,14 +2028,12 @@ gcm_session_sensor_added_cb (CdClient *client,
                              CdSensor *sensor,
                              GsdColorManager *manager)
 {
-#ifdef HAVE_LIBCANBERRA
         ca_context_play (ca_gtk_context_get (), 0,
                          CA_PROP_EVENT_ID, "device-added",
                          /* TRANSLATORS: this is the application name */
                          CA_PROP_APPLICATION_NAME, _("GNOME Settings Daemon Color Plugin"),
                         /* TRANSLATORS: this is a sound description */
                          CA_PROP_EVENT_DESCRIPTION, _("Color calibration device added"), NULL);
-#endif
 
         /* open up the color prefs window */
         gcm_session_exec_control_center (manager);
@@ -2115,14 +2044,12 @@ gcm_session_sensor_removed_cb (CdClient *client,
                                CdSensor *sensor,
                                GsdColorManager *manager)
 {
-#ifdef HAVE_LIBCANBERRA
         ca_context_play (ca_gtk_context_get (), 0,
                          CA_PROP_EVENT_ID, "device-removed",
                          /* TRANSLATORS: this is the application name */
                          CA_PROP_APPLICATION_NAME, _("GNOME Settings Daemon Color Plugin"),
                         /* TRANSLATORS: this is a sound description */
                          CA_PROP_EVENT_DESCRIPTION, _("Color calibration device removed"), NULL);
-#endif
 }
 
 static void
@@ -2155,46 +2082,11 @@ gcm_session_active_changed_cb (GnomeSettingsSession *session,
         priv->session_state = state_new;
 }
 
-static void
-gsd_color_manager_set_property (GObject        *object,
-                                guint           prop_id,
-                                const GValue   *value,
-                                GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-gsd_color_manager_get_property (GObject        *object,
-                               guint           prop_id,
-                               GValue         *value,
-                               GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-gsd_color_manager_dispose (GObject *object)
-{
-        G_OBJECT_CLASS (gsd_color_manager_parent_class)->dispose (object);
-}
-
 static void
 gsd_color_manager_class_init (GsdColorManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = gsd_color_manager_get_property;
-        object_class->set_property = gsd_color_manager_set_property;
-        object_class->dispose = gsd_color_manager_dispose;
         object_class->finalize = gsd_color_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (GsdColorManagerPrivate));
