@@ -940,32 +940,6 @@ gsd_print_notifications_manager_stop (GsdPrintNotificationsManager *manager)
         scp_handler (manager, FALSE);
 }
 
-static void
-gsd_print_notifications_manager_set_property (GObject        *object,
-                                              guint           prop_id,
-                                              const GValue   *value,
-                                              GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
-static void
-gsd_print_notifications_manager_get_property (GObject        *object,
-                                              guint           prop_id,
-                                              GValue         *value,
-                                              GParamSpec     *pspec)
-{
-        switch (prop_id) {
-        default:
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
-                break;
-        }
-}
-
 static GObject *
 gsd_print_notifications_manager_constructor (GType                  type,
                                              guint                  n_construct_properties,
@@ -980,21 +954,12 @@ gsd_print_notifications_manager_constructor (GType                  type,
         return G_OBJECT (print_notifications_manager);
 }
 
-static void
-gsd_print_notifications_manager_dispose (GObject *object)
-{
-        G_OBJECT_CLASS (gsd_print_notifications_manager_parent_class)->dispose (object);
-}
-
 static void
 gsd_print_notifications_manager_class_init (GsdPrintNotificationsManagerClass *klass)
 {
         GObjectClass   *object_class = G_OBJECT_CLASS (klass);
 
-        object_class->get_property = gsd_print_notifications_manager_get_property;
-        object_class->set_property = gsd_print_notifications_manager_set_property;
         object_class->constructor = gsd_print_notifications_manager_constructor;
-        object_class->dispose = gsd_print_notifications_manager_dispose;
         object_class->finalize = gsd_print_notifications_manager_finalize;
 
         g_type_class_add_private (klass, sizeof (GsdPrintNotificationsManagerPrivate));
