@@ -38,6 +38,8 @@
 #define GSD_UPDATES_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSD_TYPE_UPDATES_MANAGER, GsdUpdatesManagerPrivate))
 
 #define MAX_FAILED_GET_UPDATES              10 /* the maximum number of tries */
+#define GSD_UPDATES_ICON_NORMAL             "software-update-available-symbolic"
+#define GSD_UPDATES_ICON_URGENT             "software-update-urgent-symbolic"
 
 struct GsdUpdatesManagerPrivate
 {
@@ -142,8 +144,11 @@ get_distro_upgrades_finished_cb (GObject *object,
         /* get the results */
         results = pk_client_generic_finish (PK_CLIENT(client), res, &error);
         if (results == NULL) {
-                g_warning ("failed to get upgrades: %s",
-                           error->message);
+                if (error->domain != PK_CLIENT_ERROR ||
+                    error->code != PK_CLIENT_ERROR_NOT_SUPPORTED) {
+                        g_warning ("failed to get upgrades: %s",
+                                   error->message);
+                }
                 g_error_free (error);
                 goto out;
         }
@@ -152,7 +157,7 @@ get_distro_upgrades_finished_cb (GObject *object,
         error_code = pk_results_get_error_code (results);
         if (error_code != NULL) {
                 g_warning ("failed to get upgrades: %s, %s",
-                           pk_error_enum_to_text (pk_error_get_code (error_code)),
+                           pk_error_enum_to_string (pk_error_get_code (error_code)),
                            pk_error_get_details (error_code));
                 goto out;
         }
@@ -184,7 +189,7 @@ get_distro_upgrades_finished_cb (GObject *object,
                               NULL);
                 g_string_append_printf (string, "%s (%s)\n",
                                         name,
-                                        pk_distro_upgrade_enum_to_text (state));
+                                        pk_distro_upgrade_enum_to_string (state));
                 g_free (name);
         }
         if (string->len != 0)
@@ -192,7 +197,9 @@ get_distro_upgrades_finished_cb (GObject *object,
 
         /* TRANSLATORS: a distro update is available, e.g. Fedora 8 to Fedora 9 */
         title = _("Distribution upgrades available");
-        notification = notify_notification_new (title, string->str, NULL);
+        notification = notify_notification_new (title,
+                                                string->str,
+                                                GSD_UPDATES_ICON_NORMAL);
         notify_notification_set_app_name (notification, _("Software Updates"));
         notify_notification_set_timeout (notification, NOTIFY_EXPIRES_NEVER);
         notify_notification_set_urgency (notification, NOTIFY_URGENCY_NORMAL);
@@ -254,7 +261,7 @@ refresh_cache_finished_cb (GObject *object, GAsyncResult *res, GsdUpdatesManager
         error_code = pk_results_get_error_code (results);
         if (error_code != NULL) {
                 g_warning ("failed to refresh the cache: %s, %s",
-                           pk_error_enum_to_text (pk_error_get_code (error_code)),
+                           pk_error_enum_to_string (pk_error_get_code (error_code)),
                            pk_error_get_details (error_code));
                 goto out;
         }
@@ -315,7 +322,9 @@ notify_critical_updates (GsdUpdatesManager *manager, GPtrArray *array)
 
         /* do the bubble */
         g_debug ("title=%s, message=%s", title, message);
-        notification = notify_notification_new (title, message, NULL);
+        notification = notify_notification_new (title,
+                                                message,
+                                                GSD_UPDATES_ICON_URGENT);
         notify_notification_set_app_name (notification, _("Software Updates"));
         notify_notification_set_timeout (notification, 15000);
         notify_notification_set_urgency (notification, NOTIFY_URGENCY_CRITICAL);
@@ -372,7 +381,9 @@ notify_normal_updates_maybe (GsdUpdatesManager *manager, GPtrArray *array)
 
         /* do the bubble */
         g_debug ("title=%s, message=%s", title, message);
-        notification = notify_notification_new (title, message, NULL);
+        notification = notify_notification_new (title,
+                                                message,
+                                                GSD_UPDATES_ICON_NORMAL);
         notify_notification_set_app_name (notification, _("Software Updates"));
         notify_notification_set_timeout (notification, 15000);
         notify_notification_set_urgency (notification, NOTIFY_URGENCY_NORMAL);
@@ -427,7 +438,8 @@ update_check_on_battery (GsdUpdatesManager *manager)
         message = _("Automatic updates are not being installed as the computer is running on battery power");
         /* TRANSLATORS: informs user will not install by default */
         notification = notify_notification_new (_("Updates not installed"),
-                                                message, NULL);
+                                                message,
+                                                GSD_UPDATES_ICON_NORMAL);
         notify_notification_set_app_name (notification, _("Software Updates"));
         notify_notification_set_timeout (notification, 15000);
         notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
@@ -510,8 +522,8 @@ notify_update_finished (GsdUpdatesManager *manager, PkResults *results)
                               NULL);
 
                 split = pk_package_id_split (package_id);
-                g_debug ("%s, %s, %s", pk_info_enum_to_text (info),
-                           split[PK_PACKAGE_ID_NAME], summary);
+                g_debug ("%s, %s, %s", pk_info_enum_to_string (info),
+                         split[PK_PACKAGE_ID_NAME], summary);
                 if (info == PK_INFO_ENUM_BLOCKED) {
                         skipped_number++;
                         g_string_append_printf (message_text, "<b>%s</b> - %s\n",
@@ -558,7 +570,8 @@ notify_update_finished (GsdUpdatesManager *manager, PkResults *results)
 
         /* TRANSLATORS: title: system update completed all okay */
         notification = notify_notification_new (_("The system update has completed"),
-                                                 message_text->str, NULL);
+                                                 message_text->str,
+                                                 GSD_UPDATES_ICON_NORMAL);
         notify_notification_set_app_name (notification, _("Software Updates"));
         notify_notification_set_timeout (notification, 15000);
         notify_notification_set_urgency (notification, NOTIFY_URGENCY_LOW);
@@ -577,8 +590,7 @@ notify_update_finished (GsdUpdatesManager *manager, PkResults *results)
 out:
         if (message_text != NULL)
                 g_string_free (message_text, TRUE);
-        if (array != NULL)
-                g_ptr_array_unref (array);
+        g_ptr_array_unref (array);
 }
 
 static void
@@ -603,7 +615,7 @@ update_packages_finished_cb (PkTask *task,
         error_code = pk_results_get_error_code (results);
         if (error_code != NULL) {
                 g_warning ("failed to update system: %s, %s",
-                           pk_error_enum_to_text (pk_error_get_code (error_code)),
+                           pk_error_enum_to_string (pk_error_get_code (error_code)),
                            pk_error_get_details (error_code));
                 goto out;
         }
@@ -645,7 +657,9 @@ notify_failed_get_updates_maybe (GsdUpdatesManager *manager)
         /* TRANSLATORS: try again, this time launching the update viewer */
         button = _("Try again");
 
-        notification = notify_notification_new (title, message, NULL);
+        notification = notify_notification_new (title,
+                                                message,
+                                                GSD_UPDATES_ICON_NORMAL);
         notify_notification_set_app_name (notification, _("Software Updates"));
         notify_notification_set_timeout (notification, 120*1000);
         notify_notification_set_urgency (notification, NOTIFY_URGENCY_NORMAL);
@@ -688,7 +702,7 @@ package_download_finished_cb (GObject *object,
         error_code = pk_results_get_error_code (results);
         if (error_code != NULL) {
                 g_warning ("failed to download: %s, %s",
-                           pk_error_enum_to_text (pk_error_get_code (error_code)),
+                           pk_error_enum_to_string (pk_error_get_code (error_code)),
                            pk_error_get_details (error_code));
                 notify_failed_get_updates_maybe (manager);
                 goto out;
@@ -761,7 +775,7 @@ get_updates_finished_cb (GObject *object,
         error_code = pk_results_get_error_code (results);
         if (error_code != NULL) {
                 g_warning ("failed to get updates: %s, %s",
-                           pk_error_enum_to_text (pk_error_get_code (error_code)),
+                           pk_error_enum_to_string (pk_error_get_code (error_code)),
                            pk_error_get_details (error_code));
                 notify_failed_get_updates_maybe (manager);
                 goto out;
@@ -1173,13 +1187,17 @@ update_viewer_appeared_cb (GDBusConnection *connection,
 static gboolean
 file_exists_in_root (const gchar *root, const gchar *filename)
 {
-        gboolean ret;
+        gboolean ret = FALSE;
         GFile *source;
         gchar *source_path;
 
         source_path = g_build_filename (root, filename, NULL);
         source = g_file_new_for_path (source_path);
 
+        /* ignore virtual mountpoints */
+        if (!g_file_is_native (source))
+                goto out;
+
         /* an interesting file exists */
         ret = g_file_query_exists (source, NULL);
         g_debug ("checking for %s: %s", source_path, ret ? "yes" : "no");
